System-wide settings for timetable and substitution display
===========================================================

The display of timetables and substitution plans can be customised
under `Admin → Configuration → Timetables`. The section contains the
following preferences:

* **Use parent groups in timetable views**: If a lesson or substitution
  has only one group and this group has parent groups, these groups will
  be shown.
* **Limit of groups for shortening of groups**: If a user has activated
  the preference for shortening too long group lists, this limit will be
  used to determine at what number of groups shortening will happen.
* **Number of days shown on substitutions print view**: Here you can set
  the number of days that will be shown on the substitutions print view
  (PDF file).
* **Show header box in substitution views**: The header box shows all
  affected/absent teachers/groups for the current day.
* **Show parent groups in header box in substitution views instead of original groups**:
  This setting determines the same setting as `Use parent groups in timetable views`,
  but for the printout.
